| Title: | Microarray Data related methods that utlize BufferedMatrix objects |
|---|---|
| Description: | Microarray analysis methods that use BufferedMatrix objects |
| Authors: | Ben Bolstad <[email protected]> |
| Maintainer: | Ben Bolstad <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.77.0 |
| Built: | 2026-05-18 10:17:53 UTC |
| Source: | https://github.com/bioc/BufferedMatrixMethods |
Read CEL data into BufferedMatrix objects.
BufferedMatrix.justRMA(..., filenames=character(0),celfile.path=NULL, phenoData=new("AnnotatedDataFrame"), description=NULL, notes="", verbose=FALSE, background=TRUE, normalize=TRUE, cdfname = NULL)BufferedMatrix.justRMA(..., filenames=character(0),celfile.path=NULL, phenoData=new("AnnotatedDataFrame"), description=NULL, notes="", verbose=FALSE, background=TRUE, normalize=TRUE, cdfname = NULL)
... |
file names separated by comma. |
filenames |
file names in a character vector. |
celfile.path |
path where CEL files are located |
phenoData |
a
|
description |
a |
notes |
notes |
verbose |
verbosity flag |
normalize |
logical value. If |
background |
logical value. If |
cdfname |
Used to specify the name of an alternative cdf
package. If set to
|
An ExpressionSet object, containing expression values identical to
what one would get from running rma on an
AffyBatch.
Ben Bolstad [email protected]
BufferedMatrix,
BufferedMatrix.read.probematrix
Read CEL data into
BufferedMatrix
objects.
BufferedMatrix.read.celfiles(..., filenames = character(0),celfile.path=NULL)BufferedMatrix.read.celfiles(..., filenames = character(0),celfile.path=NULL)
... |
file names separated by comma. |
filenames |
file names in a character vector. |
celfile.path |
path where CEL files are located |
A BufferedMatrix
object containing the CEL file intensities.
Ben Bolstad [email protected]
BufferedMatrix,
BufferedMatrix.read.probematrix
Read CEL data into BufferedMatrix objects.
BufferedMatrix.read.probematrix(..., filenames = character(0),celfile.path=NULL,rm.mask = FALSE, rm.outliers = FALSE, rm.extra = FALSE, verbose = FALSE,which="pm",cdfname = NULL)BufferedMatrix.read.probematrix(..., filenames = character(0),celfile.path=NULL,rm.mask = FALSE, rm.outliers = FALSE, rm.extra = FALSE, verbose = FALSE,which="pm",cdfname = NULL)
... |
file names separated by comma. |
filenames |
file names in a character vector. |
celfile.path |
path where CEL files are located |
rm.mask |
should the spots marked as 'MASKS' set to |
rm.outliers |
should the spots marked as 'OUTLIERS' set to |
rm.extra |
if |
verbose |
verbosity flag |
which |
should be either "pm", "mm" or "both" |
cdfname |
Used to specify the name of an alternative cdf package. If set to
|
A list of one or two BufferedMatrix objects. Each BufferedMatrix objects is either PM or MM data. No AffyBatch is created.
Ben Bolstad [email protected]
This group of functions can be used to apply the RMA background correction, Quantile normalization and Median polish summarization to data stored in a BufferedMatrix object.
bg.correct.BufferedMatrix(x, copy=TRUE) normalize.BufferedMatrix.quantiles(x, copy=TRUE) BufferedMatrix.bg.correct.normalize.quantiles(x, copy=TRUE)bg.correct.BufferedMatrix(x, copy=TRUE) normalize.BufferedMatrix.quantiles(x, copy=TRUE) BufferedMatrix.bg.correct.normalize.quantiles(x, copy=TRUE)
x |
a
|
copy |
should the
|
In the case of normalize.BufferedMatrix.quantiles and
bg.correct.BufferedMatrix a
BufferedMatrix is
returned. The function
median.polish.summarize returns a matrix.
The function BufferedMatrix.bg.correct.normalize.quantiles
carries out both pre-processing steps with a single command.
B. M. Bolstad [email protected]